@@ -3,7 +3,6 @@ from discern.fre_shap import FeatureRelevanceSHAP
 import copy
 from discern import util
 from discern.discern_base import DisCERN
-from sklearn.preprocessing import MinMaxScaler
 
 class DisCERNTabular(DisCERN):
     """
@@ -13,7 +12,7 @@ class DisCERNTabular(DisCERN):
     def __init__(self, model, rel, p, threshold=0.0):
         """
         Init method
-
+python -m twine upload dist/*
         :param model: a trained ML model; currently supports sklearn backend
         :param rel: preferred Fature Relevance Explainer; currently supports LIME
         :param p: preferred pivot; either Q for Query or N for NUN; default is Query
@@ -34,8 +33,9 @@ class DisCERNTabular(DisCERN):
 
         """
         self.cat_feature_indices = cat_feature_indices
-        self.scalar = MinMaxScaler()
-        self.norm_train_data= self.scalar.fit_transform(self.train_data)
+        # self.scalar = MinMaxScaler()
+        # self.norm_train_data= self.scalar.fit_transform(self.train_data)
+        self.norm_train_data= self.train_data
 
         # if all validations pass, we can proceed to initialising the feature relevance explainer
         self.init_rel()
@@ -64,7 +64,9 @@ class DisCERNTabular(DisCERN):
         :returns: the number of feature changes i.e. sparsity
         :returns: the amount of feature change i.e. proximity
         """
-        norm_test_instance = self.scalar.transform([test_instance])[0]
+        # norm_test_instance = self.scalar.transform([test_instance])[0]
+
+        norm_test_instance = test_instance
 
         sparsity = 0.0
         proximity = 0.0
